==========
vsgen-ptvs
==========

`vsgen-ptvs`_ is a plugin to `vsgen`_ that generates `Python Tools for Visual Studio`_ projects.

It is supported on Python versions 2.7, 3.3, 3.4, 3.5, and 3.6 and the code is open source, `available on github`_.

This documentation was built from the |version| (|release|) snapshot of the code.

.. _user-docs:
.. toctree::
   :maxdepth: 2
   :caption: User Documentation

   user/overview
   user/objects
   user/files
   user/faq

.. _dev-docs:
.. toctree::
   :maxdepth: 1
   :caption: Developer Documentation

   dev/release

.. _api-docs:
.. toctree::
   :maxdepth: 2
   :caption: API Documentation

   vsgenptvs <apidoc/vsgenptvs>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _vsgen: https://pypi.python.org/pypi/vsgen
.. _vsgenptvs: https://pypi.python.org/pypi/vsgen-ptvs
.. _Python Tools for Visual Studio: https://github.com/Microsoft/PTVS
.. _available on github: https://github.com/dbarsam/python-vsgen-ptvs
